@@ -11,7 +11,7 @@ import ddtcv
 from typing import Union
 from threading import Thread
 from ctypes import windll
-from ddtank import stop_thread
+from ddtank.utils.stop_thread import stop_thread
 
 VkKeyScanA = windll.user32.VkKeyScanA
 
@@ -129,6 +129,7 @@ class Status:
 
     def stop(self):
         stop_thread(self.thread)
+        self.thread = None
 
     @staticmethod
     def __sleep(period: int):
@@ -295,7 +296,7 @@ class Status:
             def wrapper(*args, **kwargs):
                 start = time.perf_counter()
                 result = func(*args, **kwargs)
-                print(f'{func.__name__} running time: {time.perf_counter() - start}')
+                # print(f'{func.__name__} running time: {time.perf_counter() - start}')
                 return result
             return wrapper
 
@@ -378,6 +379,8 @@ class Status:
                 if circle_pos:
                     return circle_pos
                 else:
+                    if is_circle:
+                        return None
                     self.__sleep(100)
 
         self.capture()
@@ -387,8 +390,7 @@ class Status:
         self.box_pos, self.box_width = read_white_box()
         self.blues, self.cur_pos = read_blue()
         self.reds = read_red()
-        if is_circle:
-            self.circle = read_circle()
+        self.circle = read_circle()
 
     def shot(self, shot_angle, shot_strength: int, shot_item: tuple = None):
         """
